@@ -25,6 +25,7 @@
 #define __APPSTREAM_GLIB_H_INSIDE__
 
 #include <as-app.h>
+#include <as-app-builder.h>
 #include <as-bundle.h>
 #include <as-checksum.h>
 #include <as-enums.h>
@@ -33,11 +34,13 @@
 #include <as-inf.h>
 #include <as-node.h>
 #include <as-problem.h>
+#include <as-profile.h>
 #include <as-provide.h>
 #include <as-release.h>
 #include <as-screenshot.h>
 #include <as-store.h>
 #include <as-tag.h>
+#include <as-translation.h>
 #include <as-version.h>
 #include <as-utils.h>
 
